@@ -1,7 +1,7 @@
+from contextlib import suppress
 from .Range import Range
-from collections.abc import Iterable
 from ._helper import _is_iterable_non_string, _LinkedList, Inf, Rangelike
-from typing import TypeVar, Iterator, Union, Any
+from typing import TypeVar, Iterable, Iterator, Union, Any, List
 
 
 T = TypeVar('T', bound=Any)
@@ -363,7 +363,7 @@ class RangeSet(Iterable):
             raise IndexError(f"'{item}' could not be isolated")
         raise IndexError(f"'{item}' is not in this RangeSet")
 
-    def ranges(self) -> list[Range]:
+    def ranges(self) -> List[Range]:
         """
         Returns a `list` of the Range objects that this RangeSet contains
 
@@ -477,17 +477,13 @@ class RangeSet(Iterable):
         """
         if self == item:
             return True
-        try:
+        with suppress(TypeError):
             if _is_iterable_non_string(item):
-                try:
+                with suppress(ValueError):
                     return all(
                         any(subitem in rng for rng in self._ranges)
                         for subitem in RangeSet._to_rangeset(item)
                     )
-                except ValueError:
-                    pass
-        except TypeError:
-            pass
         return any(item in rng for rng in self._ranges)
 
     def __invert__(self) -> 'RangeSet':
